# Table of Contents

- [filtering-in-graphql](<./filtering-in-graphql.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Filtering in GraphQL](<./Filtering-in-GraphQL.md>)
  - [Filters](<./Filtering-in-GraphQL/Filters.md>)
  - [Logical Operators](<./Filtering-in-GraphQL/Logical-Operators.md>)
  - [Facet Keys](<./Filtering-in-GraphQL/Facet-Keys.md>)
  - [Global Facet Keys](<./Filtering-in-GraphQL/Global-Facet-Keys.md>)
  - [Facet Keys Specific to Fact Sheet Types](<./Filtering-in-GraphQL/Facet-Keys-Specific-to-Fact-Sheet-Types.md>)
  - [Retrieving Facet Filters](<./Filtering-in-GraphQL/Retrieving-Facet-Filters.md>)
  - [Examples](<./Filtering-in-GraphQL/Examples.md>)
  - [Was this page helpful?](<./Filtering-in-GraphQL/Was-this-page-helpful.md>)
